@@ -15,7 +15,7 @@ model.Matrix <- function(object, data = environment(object),
 	## as standard	model.matrix() but producing a	"ddenseModelMatrix":
 	m <- model.matrix(object, data=data,
 			  contrasts.arg=contrasts.arg, xlev=xlev, ...)
-	new("ddenseModelMatrix", as(m, "dgeMatrix"),
+	new("ddenseModelMatrix", as(m, "generalMatrix"),
 	    assign = attr(m, "assign"),
 	    contrasts = if(is.null(ctr <- attr(m,"contrasts")))list() else ctr)
     }
@@ -29,6 +29,7 @@ model.Matrix <- function(object, data = environment(object),
 ## ----- both  dgCMatrix_cholsol and  dgCMatrix_qrsol are only called from here!
 lm.fit.sparse <- function(x, y, w = NULL, offset = NULL,
 			  method = c("qr", "cholesky"),
+                          ## (tol, singular.ok): UNused
 			  tol = 1e-7, singular.ok = TRUE, order = NULL,
 			  transpose = FALSE)
 ### Fit a linear model, __ given __ a sparse model matrix 'x'
@@ -69,8 +70,7 @@ lm.fit.sparse <- function(x, y, w = NULL, offset = NULL,
 	    y  <- if (ny > 1L) y[ok, , drop = FALSE] else y[ok]
 	}
 	wts <- sqrt(w)
-	## keep the unweighted (x,y):
-	y. <- y ## x. <- x
+	## keep the unweighted (x,y):  y. <- y ## x. <- x
 	x <- x * wts
 	y <- y * wts
     }
@@ -83,16 +83,14 @@ lm.fit.sparse <- function(x, y, w = NULL, offset = NULL,
 
     switch(method,
 	   "cholesky" = {
-	       r <- .Call(Matrix:::dgCMatrix_cholsol, # has AS_CHM_SP(x)
-			  as(if(transpose) tx else t(x), "CsparseMatrix"), y)
+	       r <- .solve.dgC.chol(as(if(transpose) tx else t(x), "CsparseMatrix"), y)
 	       coef <- r[["coef"]]
 	   },
 	   "qr" = {
-	       ## FIXME: should improve C code here, to return more
-	       coef <- .Call(Matrix:::dgCMatrix_qrsol, # has AS_CSP(): must be dgC or dtC:
-			     if(cld@className %in% c("dtCMatrix", "dgCMatrix")) x
-			     else as(x, "dgCMatrix"),
-			     y, order)
+	       coef <-
+		   .solve.dgC.qr(if(cld@className %in% c("dtCMatrix", "dgCMatrix")) x
+				 else as(x, "CsparseMatrix"),
+				 y, order)
 	       ## for now -- FIXME --
 	       return(coef)
 	   },
@@ -242,7 +240,7 @@ mkRespMod <- function(fr, family = NULL, nlenv = NULL, nlmod = NULL)
         } else {
             ll$Class <- "nlsRespMod"
             ll$nlenv <- nlenv
-            ll$nlmod <- Quote(nlmod)
+	    ll$nlmod <- quote(nlmod)
             ll$sqrtXwt <- grad
             ll$pnames <- colnames(ll$sqrtXwt)
         }
